#!/usr/bin/python

from django.db import models

class Address(models.Model):
    street = models.CharField(max_length=200)
    number = models.IntegerField()
    zip_code = models.CharField(max_length=12)
    city = models.CharField(max_length=200)
    country = models.CharField(max_length=200)

    def address_path(instance, filename):
        path = f'images/address/{filename}'
        print(path)
        return path

    image = models.ImageField(upload_to=address_path, max_length=32768)

    class Meta:
        verbose_name_plural = "Addresses"


class CompanyImages(models.Model):
    def image_path(instance, filename):
        path = f'images/company/images/{filename}'
        print(path)
        return path

    image = models.ImageField(upload_to=image_path, max_length=32768)

class Company(models.Model):
    name = models.CharField(max_length=200)
    address = models.OneToOneField(Address, on_delete=models.CASCADE)
    address_set = models.ManyToManyField(Address, related_name='address_set')

    def logo_path(instance, filename):
        path = f'images/company/logo/{filename}'
        print(path)
        return path

    logo = models.ImageField(upload_to=logo_path, max_length=32768)

    image_set = models.ManyToManyField(CompanyImages, related_name='image_set')

    class Meta:
        verbose_name_plural = "Companies"

class Person(models.Model):
    first_name = models.CharField(max_length=200)
    infix = models.CharField(max_length=1)
    last_name = models.CharField(max_length=200)
    phone_number = models.CharField(max_length=15)
    email = models.EmailField(max_length=254)
    address = models.OneToOneField(Address, on_delete=models.CASCADE)
    company = models.ForeignKey(Company, on_delete=models.CASCADE)

    def person_path(instance, filename):
        path = f'images/person/{filename}'
        print(path)
        return path

    image = models.ImageField(upload_to=person_path, max_length=32768)

    class Meta:
        verbose_name_plural = "Persons"
