#!/bin/bash

set -vx

export PROJECT_ID=django-app-unicodex
export REGION=europe-west4
export SERVICE_NAME=unicodex
export CLOUDRUN_SA=${SERVICE_NAME}@${PROJECT_ID}.iam.gserviceaccount.com
export INSTANCE_NAME=${PROJECT_ID}-cloudsql
export GS_PROJECT_ID=django-app-unicodex

source .env

sed -e 's:^\(DATABASE_URL.\+@db.\+\)$:#\1:' \
    -e 's:^#\(DATABASE_URL.\+cloudsql.\+\)$:\1:' \
    -e 's:^#\(GS_MEDIA_BUCKET_NAME.\+\)$:\1:' \
    -e 's:^#\(GS_STATIC_BUCKET_NAME.\+\)$:\1:' \
    -i .env


# Recreate DDBB
################
# export DATABASE_NAME=unicodex
# gcloud sql databases delete $DATABASE_NAME --instance=$INSTANCE_NAME
# gcloud sql databases create $DATABASE_NAME --instance=$INSTANCE_NAME || exit 1


# Recreate secrets
###################
#for i in django_settings SUPERPASS SUPERUSER; do gcloud secrets delete $i; done
#gcloud secrets create django_settings --replication-policy automatic --data-file .env || exit 1
#
#export PROJECTNUM=$(gcloud projects describe ${PROJECT_ID} --format 'value(projectNumber)')
#export CLOUDBUILD_SA=${PROJECTNUM}@cloudbuild.gserviceaccount.com
#
#gcloud secrets add-iam-policy-binding django_settings \
#  --member serviceAccount:$CLOUDRUN_SA \
#  --role roles/secretmanager.secretAccessor || exit 1
#
#gcloud secrets add-iam-policy-binding django_settings \
#  --member serviceAccount:$CLOUDBUILD_SA \
#  --role roles/secretmanager.secretAccessor || exit 1
#
#for SECRET in SUPERUSER SUPERPASS; do
#  gcloud secrets create $SECRET --replication-policy automatic || exit 1
#
#  echo -n "${!SECRET}" | gcloud secrets versions add $SECRET --data-file=- || exit 1
#
#  gcloud secrets add-iam-policy-binding $SECRET \
#    --member serviceAccount:$CLOUDBUILD_SA \
#    --role roles/secretmanager.secretAccessor || exit 1
#done


gcloud builds submit --tag gcr.io/$PROJECT_ID/$SERVICE_NAME || exit 1

gcloud run deploy $SERVICE_NAME \
  --allow-unauthenticated \
  --image gcr.io/$PROJECT_ID/$SERVICE_NAME \
  --add-cloudsql-instances $PROJECT_ID:$REGION:$INSTANCE_NAME \
  --service-account $CLOUDRUN_SA || exit 1


#gcloud run services list || exit 1
export SERVICE_URL=$(gcloud run services describe $SERVICE_NAME --format "value(status.url)")
#
echo $SERVICE_URL
#
gcloud run services update $SERVICE_NAME \
  --update-env-vars "CURRENT_HOST=${SERVICE_URL}" || exit 1

# migrate and deploy
gcloud builds submit \
  --config .cloudbuild/build-migrate-deploy.yaml \
  --substitutions "_REGION=${REGION},_INSTANCE_NAME=${INSTANCE_NAME},_SERVICE=${SERVICE_NAME}" || exit 1

sed -e 's:^#\(DATABASE_URL.\+@db.\+\)$:\1:' \
    -e 's:^\(DATABASE_URL.\+cloudsql.\+\)$:#\1:' \
    -e 's:^\(GS_MEDIA_BUCKET_NAME.\+\)$:#\1:' \
    -e 's:^\(GS_STATIC_BUCKET_NAME.\+\)$:#\1:' \
    -i .env
